==> pyccel-0.9.9.tar.gz: pyccel-0.9.9/tests/internal/scripts/mpi/__pyccel__/line.f90 <==

program prog_line

use mpi
implicit none

integer(kind=8), allocatable :: a (:,:) 
integer(kind=4) :: source  
integer(kind=4) :: rank  
integer(kind=4), allocatable :: status (:) 
integer(kind=4) :: tag  
integer(kind=4) :: dest  
integer(kind=4) :: comm  
integer(kind=4) :: size  
integer(kind=4) :: ierr  
integer(kind=4) :: nb_lines  
integer(kind=4) :: type_line  
integer(kind=4) :: count  
integer(kind=4) :: blocklength  
integer(kind=4) :: nb_columns  
!coding: utf-8



















!we need to declare these variables somehow,
!since we are calling mpi subroutines
ierr = Int(-1_8, 4)
size = Int(-1_8, 4)
rank = Int(-1_8, 4)


call mpi_init(ierr)


comm = mpi_comm_world


call mpi_comm_size(comm, size, ierr)
call mpi_comm_rank(comm, rank, ierr)


nb_lines = Int(3_8, 4)
nb_columns = Int(4_8, 4)
tag = Int(100_8, 4)


allocate(a(0:nb_columns - 1_8, 0:nb_lines - 1_8))
a = 0
allocate(status(0:mpi_status_size - 1_8))
status = 0


!Initialization of the matrix on each process
a(:, :) = rank + 1000_8


!Definition of the type_line datatype
blocklength = Int(1_8, 4)
type_line = Int(-1_8, 4)
  call mpi_type_vector(nb_columns, blocklength, nb_lines, MPI_INTEGER8, &
      type_line, ierr)


  !Validation of the type_line datatype
  call mpi_type_commit(type_line, ierr)


  !Sending of the first column
  if (rank == 0 ) then
    dest = Int(1_8, 4)
    call mpi_send(a(0, 1_8), nb_columns, MPI_INTEGER8, dest, tag, comm, &
      ierr)
  end if
  !Reception in the last column
  if (rank == 1_8 ) then
    count = Int(1_8, 4)
    source = Int(0, 4)
    call mpi_recv(a(0, nb_lines - 1_8), count, type_line, source, tag, &
      comm, status, ierr)
  end if
  print *, 'I process ', rank, ', has a = ', a


  !Free the datatype
  call mpi_type_free(type_line, ierr)


  call mpi_finalize(ierr)

  end program prog_line

==> pyccel-0.9.10.tar.gz: pyccel-0.9.10/tests/internal/scripts/mpi/__pyccel__/line.f90 <==

program prog_line

use mpi
implicit none

integer(kind=4)  :: ierr  
integer(kind=4)  :: blocklength  
integer(kind=8), allocatable  :: a (:,:) 
integer(kind=4)  :: size  
integer(kind=4)  :: count  
integer(kind=4)  :: source  
integer(kind=4)  :: rank  
integer(kind=4)  :: nb_lines  
integer(kind=4)  :: type_line  
integer(kind=4), allocatable  :: status (:) 
integer(kind=4)  :: comm  
integer(kind=4)  :: dest  
integer(kind=4)  :: nb_columns  
integer(kind=4)  :: tag  
!coding: utf-8



















!we need to declare these variables somehow,
!since we are calling mpi subroutines
ierr = Int(-1_8, 4)
size = Int(-1_8, 4)
rank = Int(-1_8, 4)


call mpi_init(ierr)


comm = mpi_comm_world


call mpi_comm_size(comm, size, ierr)
call mpi_comm_rank(comm, rank, ierr)


nb_lines = Int(3_8, 4)
nb_columns = Int(4_8, 4)
tag = Int(100_8, 4)


allocate(a(0:nb_columns - 1_8, 0:nb_lines - 1_8))
a = 0
allocate(status(0:mpi_status_size - 1_8))
status = 0


!Initialization of the matrix on each process
a(:, :) = rank + 1000_8


!Definition of the type_line datatype
blocklength = Int(1_8, 4)
type_line = Int(-1_8, 4)
  call mpi_type_vector(nb_columns, blocklength, nb_lines, MPI_INTEGER8, &
      type_line, ierr)


  !Validation of the type_line datatype
  call mpi_type_commit(type_line, ierr)


  !Sending of the first column
  if (rank == 0_8 ) then
    dest = Int(1_8, 4)
    call mpi_send(a(0_8, 1_8), nb_columns, MPI_INTEGER8, dest, tag, comm &
      , ierr)
  end if
  !Reception in the last column
  if (rank == 1_8 ) then
    count = Int(1_8, 4)
    source = Int(0_8, 4)
    call mpi_recv(a(0_8, nb_lines - 1_8), count, type_line, source, tag, &
      comm, status, ierr)
  end if
  print *, 'I process ', rank, ', has a = ', a


  !Free the datatype
  call mpi_type_free(type_line, ierr)


  call mpi_finalize(ierr)

  end program prog_line
